--[[--------------------------------------------------------------
Loot Spec Icon
by Sunsequent

Small icon on player portrait showing loot specialization.
Left click changes loot spec to the next one, right click sets it
to Current Specialization.

Version 1.0.1
Release Date 22.11.2020
--------------------------------------------------------------]]--

---- Version 1.0.1
-- Added localization

--SELECT_LOOT_SPECIALIZATION = "Loot Specialization";
--ERR_LOOT_SPEC_CHANGED_S = "Loot Specialization set to: %s";
--LOOT_SPECIALIZATION_DEFAULT = "Current Specialization ( %s )";
--EMBLEM_SYMBOL = "Icon";
--NEXT = "Next";
--REFORGE_CURRENT = "Current";
--LFG_TYPE_NONE = "None";

BINDING_HEADER_LOOTSPECICON = SELECT_LOOT_SPECIALIZATION.." "..EMBLEM_SYMBOL;

_G["BINDING_NAME_CLICK LootSpecIconButton:LeftButton"] = NEXT.." "..SELECT_LOOT_SPECIALIZATION
_G["BINDING_NAME_CLICK LootSpecIconButton:RightButton"] = REFORGE_CURRENT.." "..SELECT_LOOT_SPECIALIZATION

local lootSpecIconClicked = false;
local currentSpecializationLabel;

local f = CreateFrame("Frame")
f:SetScript("OnEvent", function(self, event, ...)
	if event == "ADDON_LOADED" then
		local loadedAddon = select(1, ...);
		
		if loadedAddon == "LootSpecIcon" then
			currentSpecializationLabel = (string.gsub((string.gsub(LOOT_SPECIALIZATION_DEFAULT, "%( ", "%(")), " %)", "%)"))
			LootSpecIconButton:SetScale(0.9);
		end
	else
		local localizedClass, class, classID = UnitClass("player");
		local numClassSpecializations = GetNumSpecializationsForClassID(classID);
		
		local icon = 134400;
		local texCoords = { 0, 0, 0, 1, 1, 0, 1, 1 };
		local currentLootSpec = GetLootSpecialization();
		if currentLootSpec == 0 then
			local currentSpec = GetSpecialization();
			if currentSpec then
				if currentSpec <= numClassSpecializations then
					icon = select(4, GetSpecializationInfo(currentSpec));
				else
					icon = "Interface\\TargetingFrame\\UI-Classes-Circles";
					texCoords = CLASS_ICON_TCOORDS[strupper(class)];
				end
			end		
		else
			icon = select(4, GetSpecializationInfoByID(currentLootSpec));
		end
		
		LootSpecIconBackground:SetTexture(icon);
		LootSpecIconBackground:SetTexCoord(unpack(texCoords));
		LootSpecIconButton:Show();
		
		if lootSpecIconClicked and GameTooltip:IsShown() and GameTooltip:GetOwner() == LootSpecIconButton then
			LootSpecIcon_ShowLootSpecializationTooltip();
		end
		
		lootSpecIconClicked = false;
	end
end)
f:RegisterEvent("ADDON_LOADED");
f:RegisterEvent("PLAYER_ENTERING_WORLD");
f:RegisterEvent("PLAYER_SPECIALIZATION_CHANGED");
f:RegisterEvent("PLAYER_LOOT_SPEC_UPDATED");

function LootSpecIcon_SetNextLootSpecialization(self, button)
	lootSpecIconClicked = true;
	local localizedClass, _, classID = UnitClass("player");
	local numClassSpecializations = GetNumSpecializationsForClassID(classID);
	
	if button=="LeftButton" then
		local currentLootSpecID = GetLootSpecialization();
		local currentLootSpecNum;
		local specIDToSet;
		
		if currentLootSpecID == 0 then
			specIDToSet = GetSpecializationInfoForClassID(classID, 1);		
		else
			for specNum = 1, numClassSpecializations do
				local specID = GetSpecializationInfoForClassID(classID, specNum);
				
				if currentLootSpecID == specID then
					currentLootSpecNum = specNum;
					break;
				end
			end
			
			if currentLootSpecNum == numClassSpecializations then
				specIDToSet = GetSpecializationInfoForClassID(classID, 1);			
			else
				specIDToSet = GetSpecializationInfoForClassID(classID, currentLootSpecNum + 1);			
			end
		end
		
		SetLootSpecialization(specIDToSet);
	elseif button=="RightButton" then
		local currentSpec = GetSpecialization();
		local currentSpecName = LFG_TYPE_NONE;
		if currentSpec then			
			if currentSpec <= numClassSpecializations then
				currentSpecName = select(2, GetSpecializationInfo(currentSpec));
			else
				currentSpecName = localizedClass;
			end
		end
		
		DEFAULT_CHAT_FRAME:AddMessage((ERR_LOOT_SPEC_CHANGED_S):format((currentSpecializationLabel):format(currentSpecName)), 255/255, 255/255, 0/255);
		SetLootSpecialization(0);
	end
end

function LootSpecIcon_ShowLootSpecializationTooltip()
	local currentLootSpec = GetLootSpecialization();
	local _, name = GetSpecializationInfoByID(currentLootSpec);
	local localizedClass, _, classID = UnitClass("player");
	local numClassSpecializations = GetNumSpecializationsForClassID(classID);

	GameTooltip:Hide();
	GameTooltip:SetOwner(LootSpecIconButton, "ANCHOR_RIGHT");

	if name then
		GameTooltip:AddLine(SELECT_LOOT_SPECIALIZATION..": "..name);
	else
		local currentSpec = GetSpecialization();
		local currentSpecName = LFG_TYPE_NONE;
		if currentSpec then
			if currentSpec <= numClassSpecializations then
				currentSpecName = select(2, GetSpecializationInfo(currentSpec));
			else
				currentSpecName = localizedClass;
			end
		end
		
		GameTooltip:AddLine(SELECT_LOOT_SPECIALIZATION..": "..(currentSpecializationLabel):format(currentSpecName));
	end
	
	GameTooltip:Show();
end
